@@ -10,6 +10,7 @@ import torch
 from soco_encoders.SentenceTransformer import SentenceTransformer
 from tqdm import tqdm
 from soco_encoders.models.module_bases import BaseEncoder
+import pickle
 
 
 class TransformerWrapper(BaseEncoder):
@@ -172,7 +173,10 @@ class TermTransformer(TransformerWrapper):
         self.device = config.device
 
         self.term_embedding = torch.load(os.path.join(model_dir, 'term_embeddings.bin'), map_location=self.device)
-        self.term_vocab = json.load(open(os.path.join(model_dir, 'term_vocab.json')))
+        if os.path.isfile(os.path.join(model_dir, 'term_vocab.pkl')):
+            self.term_vocab = pickle.load(open(os.path.join(model_dir, 'term_vocab.pkl'),"rb"))
+        else:
+            self.term_vocab = json.load(open(os.path.join(model_dir, 'term_vocab.json')))
 
         if config.use_gpu:
             self.logger.info("Use pytorch device: {}".format(self.device))
